==> haskell-validity-0.12.1.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity
version:              0.12.1.0
visibility:           public
id:                   validity-0.12.1.0-FNj3rkPEIDkHTD4iAxU4NK
key:                  validity-0.12.1.0-FNj3rkPEIDkHTD4iAxU4NK
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity typeclass
description:
    For more info, see <https://github.com/NorfairKing/validity the readme>.

    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/validity-aeson validity-aeson>

    * <https://hackage.haskell.org/package/validity-bytestring validity-bytestring>

    * <https://hackage.haskell.org/package/validity-containers validity-containers>

    * <https://hackage.haskell.org/package/validity-path validity-path>

    * <https://hackage.haskell.org/package/validity-scientific validity-scientific>

    * <https://hackage.haskell.org/package/validity-text validity-text>

    * <https://hackage.haskell.org/package/validity-time validity-time>

    * <https://hackage.haskell.org/package/validity-unordered-containers validity-unordered-containers>

    * <https://hackage.haskell.org/package/validity-uuid validity-uuid>

    * <https://hackage.haskell.org/package/validity-vector validity-vector>

category:             Validity
abi:                  9848004fd994654dc9e068ca2cd601a4
exposed:              True
exposed-modules:      Data.Validity
hidden-modules:       Paths_validity
import-dirs:          /usr/lib/ghc-9.4.8/site-local/validity-0.12.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/validity-0.12.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/validity-0.12.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity
hs-libraries:         HSvalidity-0.12.1.0-FNj3rkPEIDkHTD4iAxU4NK
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-validity/html/validity.haddock
haddock-html:         /usr/share/doc/haskell-validity/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validity-0.12.1.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity
version:              0.12.1.0
visibility:           public
id:                   validity-0.12.1.0-9KbPKVyeSIK9u61SXyCpH7
key:                  validity-0.12.1.0-9KbPKVyeSIK9u61SXyCpH7
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity typeclass
description:
    For more info, see <https://github.com/NorfairKing/validity the readme>.

    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/validity-aeson validity-aeson>

    * <https://hackage.haskell.org/package/validity-bytestring validity-bytestring>

    * <https://hackage.haskell.org/package/validity-containers validity-containers>

    * <https://hackage.haskell.org/package/validity-path validity-path>

    * <https://hackage.haskell.org/package/validity-scientific validity-scientific>

    * <https://hackage.haskell.org/package/validity-text validity-text>

    * <https://hackage.haskell.org/package/validity-time validity-time>

    * <https://hackage.haskell.org/package/validity-unordered-containers validity-unordered-containers>

    * <https://hackage.haskell.org/package/validity-uuid validity-uuid>

    * <https://hackage.haskell.org/package/validity-vector validity-vector>

category:             Validity
abi:                  734c556956efbfcc6dbad3387fce9fc6
exposed:              True
exposed-modules:      Data.Validity
hidden-modules:       Paths_validity
import-dirs:          /usr/lib/ghc-9.4.8/site-local/validity-0.12.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/validity-0.12.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/validity-0.12.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity
hs-libraries:         HSvalidity-0.12.1.0-9KbPKVyeSIK9u61SXyCpH7
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-validity/html/validity.haddock
haddock-html:         /usr/share/doc/haskell-validity/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
